@@ -18,15 +18,10 @@ $SIG{'TERM'} = sub {
 	};
 
 while(!$dead) {
-	if (!-x $ARGV[0]) {
-		print STDERR "PHP command $ARGV[0] does not exist!\n";
-		exit(2);
-		}
 	my $start = time();
 	$childpid = fork();
 	if ($childpid == 0) {
 		exec(@ARGV);
-		exit(1);
 		}
 	waitpid($childpid, 0);
 
