@@ -1,4 +1,4 @@
-# Common functions for Nginx config file
+# Common functions for NginX config file
 
 use strict;
 use warnings;
@@ -54,22 +54,6 @@ undef($get_config_parent_cache);
 undef($get_config_cache);
 }
 
-# remove_hash_comment(line)
-# Returns the line with comments removed
-sub remove_hash_comment
-{
-my ($l) = @_;
-if ($l =~ /".*#.*"/) {
-	# Comment inside quotes, so only remove any comment outside quotes
-	$l =~ s/#[^"]*$//;
-	}
-else {
-	# Remove all comments
-	$l =~ s/#.*$//;
-	}
-return $l;
-}
-
 # read_config_file(file, [preserve-includes])
 # Returns an array ref of nginx config objects
 sub read_config_file
@@ -88,7 +72,7 @@ my @lines = <$fh>;
 close($fh);
 while(@lines) {
 	my $l = shift(@lines);
-	$l = &remove_hash_comment($l);
+	$l =~ s/#.*$//;
 	my $slnum = $lnum;
 
 	# If line doesn't end with { } or ; , it must be continued on the
@@ -96,7 +80,7 @@ while(@lines) {
 	while($l =~ /\S/ && $l !~ /[\{\}\;]\s*$/ && @lines) {
 		my $nl = shift(@lines);
 		if ($nl =~ /\S/) {
-			$nl = &remove_hash_comment($nl);
+			$nl =~ s/#.*$//;
 			$l .= " ".$nl;
 			}
 		$lnum++;
@@ -112,7 +96,8 @@ while(@lines) {
 			   'eline' => $lnum,
 			   'members' => [ ] };
 		my $value = $1;
-		&set_split_words($ns, " ".$value);
+		$ns->{'words'} = [ &split_words(" ".$value) ];
+		$ns->{'value'} = $ns->{'words'}->[0];
 		push(@stack, $addto);
 		push(@$addto, $ns);
 		$addto = $ns->{'members'};
@@ -127,7 +112,8 @@ while(@lines) {
 			   'eline' => $lnum,
 			   'members' => [ ] };
 		my $value = $2;
-		&set_split_words($ns, $value);
+		$ns->{'words'} = [ &split_words($value) ];
+		$ns->{'value'} = $ns->{'words'}->[0];
 		push(@stack, $addto);
 		push(@$addto, $ns);
 		$addto = $ns->{'members'};
@@ -137,7 +123,7 @@ while(@lines) {
 		$addto = pop(@stack);
 		$addto->[@$addto-1]->{'eline'} = $lnum;
 		}
-	elsif ($l =~ /^\s*(\S+)((\s+("([^"]*)"|'([^']*)'|[^ ;]+))*)\s*;/) {
+	elsif ($l =~ /^\s*(\S+)((\s+("([^"]*)"|'([^']*)'|[^ ;]+))*);/) {
 		# Found a directive
 		my ($name, $value) = ($1, $2);
 		my @words = &split_words($value);
@@ -170,8 +156,7 @@ while(@lines) {
 			}
 		}
 	elsif ($l =~ /\S/) {
-		$l =~ s/\r|\n//g;
-		print STDERR "Invalid Nginx config line $l at $lnum in $file\n";
+		print STDERR "Invalid Nginx config line $l at $lnum\n";
 		}
 	$lnum++;
 	}
@@ -192,16 +177,6 @@ while($value =~ s/^\s+"([^"]+)"// ||
 return @words;
 }
 
-# set_split_words(&directive, string)
-# Set the words and value fields based on a string
-sub set_split_words
-{
-my ($ns, $value) = @_;
-my @s = &split_words($value);
-$ns->{'words'} = \@s;
-$ns->{'value'} = @s ? $s[0] : undef;
-}
-
 # get_add_to_file(name)
 # Returns the file to add new servers to, if any
 sub get_add_to_file
@@ -245,8 +220,7 @@ return wantarray ? @rv : $rv[0];
 sub find_value
 {
 my ($name, $conf) = @_;
-my @rv = map { my @w = @{$_->{'words'}};
-	       (@w ? $w[0] : undef) || $_->{'value'} } &find($name, $conf);
+my @rv = map { $_->{'words'}->[0] || $_->{'value'} } &find($name, $conf);
 return wantarray ? @rv : $rv[0];
 }
 
@@ -483,10 +457,10 @@ foreach my $w (@_) {
 	if ($w eq "") {
 		push(@rv, '""');
 		}
-	elsif ($w =~ /\s|;|\$/ && $w !~ /"/ && $w !~ /^\$/) {
+	elsif ($w =~ /\s/ && $w !~ /"/) {
 		push(@rv, "\"$w\"");
 		}
-	elsif ($w =~ /\s|;|\$/ && $w !~ /^\$/) {
+	elsif ($w =~ /\s/) {
 		push(@rv, "'$w'");
 		}
 	else {
@@ -559,13 +533,6 @@ my $dir = $dirs->{$name};
 return $dir ? $dir->{'default'} : undef;
 }
 
-sub get_default_server_param
-{
-my $ver = &get_nginx_version();
-return &compare_version_numbers($ver, "0.8.21") >= 0 ?
-	"default_server" : "default";
-}
-
 # list_nginx_modules()
 # Returns a list of enabled modules. Includes those compiled in by default
 # unless disabled, plus extra compiled in at build time.
@@ -1079,8 +1046,6 @@ for(my $i=0; defined(my $mode = $in->{$allow."_mode_".$i}); $i++) {
 		&check_ipaddress($addr) ||
 		   $addr =~ /^(\S+)\/(\d+)$/ &&
 		     &check_ipaddress("$1") && $2 > 0 && $2 <= 32 ||
-		&check_ip6address($addr) ||
-		   $addr =~ /^(\S+)\/(\d+)$/ && &check_ip6address("$1") ||
 			&error(&text('access_eaddr', $addr));
 		}
 	push(@obj, { 'name' => $mode,
@@ -1330,9 +1295,9 @@ my @servers = &find("server", $http);
 foreach my $s (@servers) {
 	my $obj = &find("server_name", $s);
 	foreach my $name (@{$obj->{'words'}}) {
-		if (defined($name) && (lc($name) eq lc($d->{'dom'}) ||
-				       lc($name) eq "www.".lc($d->{'dom'}) ||
-				       lc($name) eq "*.".lc($d->{'dom'}))) {
+		if (lc($name) eq lc($d->{'dom'}) ||
+		    lc($name) eq "www.".lc($d->{'dom'}) ||
+		    lc($name) eq "*.".lc($d->{'dom'})) {
 			return $s;
 			}
 		}
@@ -1554,40 +1519,33 @@ else {
 }
 
 # recursive_change_directives(&parent, old-value, new-value, [suffix-too],
-# 			      [prefix-too], [infix-too], [&skip-named])
+# 			      [prefix-too], [infix-too])
 # Change all directives who have a value that is the old value to the new one
 sub recursive_change_directives
 {
-my ($parent, $oldv, $newv, $suffix, $prefix, $infix, $skip) = @_;
-return if (!$oldv);
+my ($parent, $oldv, $newv, $suffix, $prefix, $infix) = @_;
 foreach my $dir (@{$parent->{'members'}}) {
-	if (!$skip || &indexof($dir->{'name'}, @$skip) < 0) {
-		my $changed = 0;
-		foreach my $w (@{$dir->{'words'}}) {
-			my $ow = $w;
-			if ($infix && $w =~ /\Q$oldv\E/) {
-				$w =~ s/\Q$oldv\E/$newv/g;
-				$changed++;
-				}
-			elsif ($suffix && $w =~ /\Q$oldv\E$/) {
-				$w =~ s/\Q$oldv\E$/$newv/;
-				$changed++;
-				}
-			elsif ($prefix && $w =~ /^\Q$oldv\E/) {
-				$w =~ s/^\Q$oldv\E/$newv/;
-				$changed++;
-				}
-			elsif ($w eq $oldv) {
-				$w = $newv;
-				$changed++;
-				}
-			if ($ow ne $w) {
-				print STDERR "changed $ow to $w\n";
-				}
+	my $changed = 0;
+	foreach my $w (@{$dir->{'words'}}) {
+		if ($infix && $w =~ /\Q$oldv\E/) {
+			$w =~ s/\Q$oldv\E/$newv/g;
+			$changed++;
 			}
-		if ($changed) {
-			&save_directive($parent, [ $dir ], [ $dir ]);
+		elsif ($suffix && $w =~ /\Q$oldv\E$/) {
+			$w =~ s/\Q$oldv\E$/$newv/g;
+			$changed++;
 			}
+		elsif ($prefix && $w =~ /^\Q$oldv\E/) {
+			$w =~ s/^\Q$oldv\E/$newv/g;
+			$changed++;
+			}
+		elsif ($w eq $oldv) {
+			$w = $newv;
+			$changed++;
+			}
+		}
+	if ($changed) {
+		&save_directive($parent, [ $dir ], [ $dir ]);
 		}
 	if ($dir->{'type'}) {
 		&recursive_change_directives($dir, $oldv, $newv,
@@ -1752,33 +1710,17 @@ my %cmds_abs = (
 	'chmod', &has_command('chmod'),
 	'kill', &has_command('kill'),
 	'sleep', &has_command('sleep'),
-	);
-if (defined(&init::enable_at_boot_as_user)) {
-	# Init system can run commands as the user
-	&init::enable_at_boot_as_user($name,
-		      "Starts Nginx PHP FastCGI server for $d->{'dom'} (Virtualmin)",
-		      "$envs $cmd >>$log 2>&1 </dev/null & $cmds_abs{'echo'} \$! >$pidfile",
-		      "$cmds_abs{'kill'} `$cmds_abs{'cat'} $pidfile`",
-		      undef,
-		      { 'fork' => 1,
-			'pidfile' => $pidfile },
-		      $d->{'user'},
-		      );
-
-	}
-else {
-	# Older Webmin requires use of command_as_user
-	&init::enable_at_boot($name,
-		      "Starts Nginx PHP FastCGI server for $d->{'dom'} (Virtualmin)",
-		      &command_as_user($d->{'user'}, 0,
-			"$envs $cmd >>$log 2>&1 </dev/null")." & $cmds_abs{'echo'} \$! >$pidfile && $cmds_abs{'chmod'} +r $pidfile",
-		      &command_as_user($d->{'user'}, 0,
-			"$cmds_abs{'kill'} `$cmds_abs{'cat'} $pidfile`")." ; $cmds_abs{'sleep'} 1",
-		      undef,
-		      { 'fork' => 1,
-			'pidfile' => $pidfile },
-		      );
-	}
+);
+&init::enable_at_boot($name,
+	      "Starts Nginx PHP FastCGI server for $d->{'dom'} (Virtualmin)",
+	      &command_as_user($d->{'user'}, 0,
+		"$envs $cmd >>$log 2>&1 </dev/null")." & $cmds_abs{'echo'} \$! >$pidfile && $cmds_abs{'chmod'} +r $pidfile",
+	      &command_as_user($d->{'user'}, 0,
+		"$cmds_abs{'kill'} `$cmds_abs{'cat'} $pidfile`")." ; $cmds_abs{'sleep'} 1",
+	      undef,
+	      { 'fork' => 1,
+		'pidfile' => $pidfile },
+	      );
 $init::init_mode = $old_init_mode;
 
 # Launch it, and save the PID
@@ -1817,7 +1759,7 @@ if ($init::init_mode eq "systemd") {
 	}
 
 # Delete socket file, if any
-if ($d->{'nginx_php_port'} && $d->{'nginx_php_port'} =~ /^(\/\S+)\/socket$/) {
+if ($d->{'nginx_php_port'} =~ /^(\/\S+)\/socket$/) {
 	my $domdir = $1;
 	&unlink_file($d->{'nginx_php_port'});
 	&unlink_file($domdir);
@@ -1834,7 +1776,6 @@ $name =~ s/\./-/g;
 return $name;
 }
 
-
 # find_php_fcgi_server(&domain)
 # Returns the full path to the PHP command used by this domain's fcgi server
 sub find_php_fcgi_server
@@ -1897,7 +1838,7 @@ sub list_fastcgi_params
 {
 my ($server) = @_;
 my $root = &find_value("root", $server);
-$root ||= '$realpath_root';
+$root ||= '$document_root';
 my @rv = (
 	[ 'GATEWAY_INTERFACE', 'CGI/1.1' ],
 	[ 'SERVER_SOFTWARE',   'nginx' ],
@@ -1942,147 +1883,12 @@ foreach my $l (@locs) {
 return undef;
 }
 
-# setup_fcgiwrap_server(&domain)
-# Starts up a fcgiwrap process running as the domain user, and enables it
-# at boot time. Returns an OK flag and the port number selected to listen on.
-sub setup_fcgiwrap_server
-{
-my ($d) =  @_;
-
-# Work out socket file for fcgiwrap
-my $socketdir = "/var/fcgiwrap";
-if (!-d $socketdir) {
-	&make_dir($socketdir, 0777);
-	}
-my $domdir = "$socketdir/$d->{'id'}.sock";
-if (!-d $domdir) {
-	&make_dir($domdir, 0770);
-	}
-my $user = &get_nginx_user();
-&set_ownership_permissions($user, $d->{'gid'}, undef, $domdir);
-my $port = "$domdir/socket";
-
-# Get the command
-my ($cmd, $log, $pidfile) = &get_fcgiwrap_server_command($d, $port);
-$cmd || return (0, $text{'fcgid_ecmd'});
-
-# Create init script
-&foreign_require("init");
-my $old_init_mode = $init::init_mode;
-if ($init::init_mode eq "upstart") {
-	$init::init_mode = "init";
-	}
-my $name = &init_script_fcgiwrap_name($d);
-my %cmds_abs = (
-	'echo', &has_command('echo'),
-	'cat', &has_command('cat'),
-	'chmod', &has_command('chmod'),
-	'kill', &has_command('kill'),
-	'sleep', &has_command('sleep'),
-	'fuser', &has_command('fuser'),
-	'rm', &has_command('rm'),
-	);
-if (defined(&init::enable_at_boot_as_user)) {
-	# Init system can run commands as the user
-	&init::enable_at_boot_as_user($name,
-		      "Nginx FCGIwrap server for $d->{'dom'} (Virtualmin)",
-		      "$cmds_abs{'rm'} -f $port ; $cmd >>$log 2>&1 </dev/null & $cmds_abs{'echo'} \$! >$pidfile && sleep 2 && $cmds_abs{'chmod'} 777 $port",
-		      "$cmds_abs{'kill'} `$cmds_abs{'cat'} $pidfile` ; ".
-		      "$cmds_abs{'sleep'} 1 ; ".
-		      "$cmds_abs{'rm'} -f $port",
-		      undef,
-		      { 'fork' => 1,
-			'pidfile' => $pidfile },
-		      $d->{'user'},
-		      );
-	}
-else {
-	# Older Webmin requires use of command_as_user
-	&init::enable_at_boot($name,
-		      "Nginx FCGIwrap server for $d->{'dom'} (Virtualmin)",
-		      &command_as_user($d->{'user'}, 0,
-			"$cmd >>$log 2>&1 </dev/null")." & $cmds_abs{'echo'} \$! >$pidfile && $cmds_abs{'chmod'} +r $pidfile && sleep 2 && $cmds_abs{'chmod'} 777 $port",
-		      &command_as_user($d->{'user'}, 0,
-			"$cmds_abs{'kill'} `$cmds_abs{'cat'} $pidfile`").
-			" ; $cmds_abs{'sleep'} 1".
-			($cmds_abs{'fuser'} ? " ; $cmds_abs{'fuser'} $port | xargs kill"
-					    : "").
-			" ; $cmds_abs{'rm'} -f $port",
-		      undef,
-		      { 'fork' => 1,
-			'pidfile' => $pidfile },
-		      );
-	}
-$init::init_mode = $old_init_mode;
-
-# Launch it, and save the PID
-&init::start_action($name);
-
-return (1, $port);
-}
-
-# delete_fcgiwrap_server(&domain)
-# Shut down the fcgiwrap process, and delete it from starting at boot
-sub delete_fcgiwrap_server
-{
-my ($d) = @_;
-
-# Stop the server
-&foreign_require("init");
-my $name = &init_script_fcgiwrap_name($d);
-&init::stop_action($name);
-
-# Delete init script
-my $old_init_mode = $init::init_mode;
-if ($init::init_mode eq "upstart") {
-        $init::init_mode = "init";
-        }
-&init::disable_at_boot($name);
-&init::delete_at_boot($name);
-$init::init_mode = $old_init_mode;
-
-# Delete socket file, if any
-if ($d->{'nginx_fcgiwrap_port'} &&
-    $d->{'nginx_fcgiwrap_port'} =~ /^(\/\S+)\/socket$/) {
-	my $domdir = $1;
-	&unlink_file($d->{'nginx_fcgiwrap_port'});
-	&unlink_file($domdir);
-	}
-}
-
-# get_fcgiwrap_server_command(&domain, port)
-# Returns a command to run the fcgiwrap server, log file and PID file
-sub get_fcgiwrap_server_command
-{
-my ($d, $port) = @_;
-my $cmd = &has_command("fcgiwrap");
-$cmd .= " -s unix:".$port;
-my $log = "$d->{'home'}/logs/fcgiwrap.log";
-my $piddir = "/var/php-nginx";
-if (!-d $piddir) {
-	&make_dir($piddir, 0777);
-	}
-my $pidfile = "$piddir/$d->{'id'}.fcgiwrap.pid";
-return ($cmd, $log, $pidfile);
-}
-
-# init_script_fcgiwrap_name(&domain)
-# Returns the name of the init script for the FCGId server
-sub init_script_fcgiwrap_name
-{
-my ($d) = @_;
-my $name = "fcgiwrap-$d->{'dom'}";
-$name =~ s/\./-/g;
-return $name;
-}
-
 # url_to_upstream(url)
 # Converts a URL like http://www.foo.com/ to an upstream host:port spec
 sub url_to_upstream
 {
 my ($url) = @_;
-my ($host, $port, $uds) = &parse_backend($url);
-return $port if ($uds);
+my ($host, $port) = &parse_http_url($url);
 $port ||= 80;
 return $host.":".$port;
 }
@@ -2097,19 +1903,14 @@ return "http://".$host.($port == 80 ? "" : ":".$port);
 }
 
 # validate_balancer_urls(url, ...)
-# Checks a bunch of URLs for syntax and resolvability.
-# If socket is used, it is not checked for resolvability.
+# Checks a bunch of URLs for syntax and resolvability
 sub validate_balancer_urls
 {
 foreach my $u (@_) {
-	my ($host, $port, $uds) = &parse_backend($u);
-	# Check for valid URL
-	if (!$uds) {
-		return &text('redirect_eurl', $u) if (!$host);
-		&to_ipaddress($host) || &to_ip6address($host) ||
-			return &text('redirect_eurlhost', $host);
-		}
-	# Socket is not checked for resolvability and already validated
+	my ($host, $port) = &parse_http_url($u);
+	return &text('redirect_eurl', $u) if (!$host);
+	&to_ipaddress($host) || &to_ip6address($host) ||
+		return &text('redirect_eurlhost', $host);
 	}
 return undef;
 }
@@ -2147,20 +1948,4 @@ foreach my $e (@_) {
 	}
 }
 
-# parse_backend(url|sock)
-# Parses a URL into host and port or unix domain socket and
-# sets a flag if it is socket
-sub parse_backend
-{
-my ($url) = @_;
-if ($url =~ /^http:\/\/(unix:\/\S+)/) {
-	return (undef, $1, 1);
-	}
-else {
-	my ($host, $port) = &parse_http_url($url);
-	return ($host, $port, 0);
-	}
-return (undef, undef, undef);
-}
-
 1;
